#!/usr/bin/env bash
#
# Requires:
# chmod, cp, install, sed
# xdg-icon-resource
#

PREFIX=$1



if [ "$PREFIX" = "" ]; then
    if [ `whoami` = "root" ]; then
	PREFIX=/usr/local
    else
        # use a xdg-like convention
	PREFIX="$HOME/.local"
    fi;
fi;


echo "Installing in " $PREFIX

# install the executable
install -d $PREFIX/bin
install -m 0755 bin/backup-monitor.py $PREFIX/bin/
echo "Binaries installed"

# install localisation data (only .mo)
LOCALISATION_PATH=$PREFIX/share/locale
install -d $LOCALISATION_PATH
LOCALISATION_FILES=`find share/locale/ -name *.mo`
for FILENAME in $LOCALISATION_FILES; do
    install -d $PREFIX/`dirname $FILENAME`
    install -m 0644 $FILENAME $PREFIX/`dirname $FILENAME`
done;
echo "Localisation files installed"

# install rsync scripts
DEST_PATH=$PREFIX/share/backup-monitor/scripts
install -d $DEST_PATH
cp -f share/backup-monitor/scripts/*.sh $DEST_PATH
# make those scripts executable
chmod u+x $DEST_PATH/*.sh
echo "Scripts installed"


# install examples
# - the config file
DEST_PATH=$PREFIX/share/backup-monitor/examples
install -d $DEST_PATH
cp -f share/backup-monitor/examples/preferences.cfg $DEST_PATH
# - the user-scripts
DEST_PATH=$PREFIX/share/backup-monitor/examples/user-scripts
install -d $DEST_PATH
cp -f share/backup-monitor/examples/user-scripts/*.sh $DEST_PATH
# make those scripts executable
chmod u+x $DEST_PATH/*.sh
echo "Examples installed"


# install  icons
# - make a local copy of the scalable icon
DEST_PATH=$PREFIX/share/backup-monitor/icons/scalable
install -d $DEST_PATH
cp -f share/backup-monitor/icons/scalable/backup-monitor.svg $DEST_PATH
# - register pixmap icons for various sizes
for size in 16 22 32 48 128; do
    xdg-icon-resource install --noupdate --novendor --size $size "share/backup-monitor/icons/${size}x${size}/backup-monitor.png"
done
xdg-icon-resource forceupdate
echo "Icons installed"


# install the documentation
DEST_PATH=$PREFIX/share/backup-monitor/doc
install -d $DEST_PATH
cp -f INSTALL $DEST_PATH
cp -f DEV $DEST_PATH
cp -f README $DEST_PATH
echo "Documentation installed"

# install the .desktop file and make it so that it starts at the
# begining of each session.
DEST_PATH=$PREFIX/share/backup-monitor
install -d $DEST_PATH
# On-the-fly replacement of $HOME with its local value
cat share/backup-monitor/backup-monitor.desktop | sed -e "s|\$HOME|${HOME}|g" > $DEST_PATH/backup-monitor.desktop
# copy it to the autostart folder if it exists
if [ -x $HOME/.config/autostart ]; then
    cp -f $DEST_PATH/backup-monitor.desktop $HOME/.config/autostart/
else
    echo "No autostart folder: you'll have to modify the session startup yourself"
fi;
echo "Desktop integration done"

echo "Installation complete."
