#!/bin/bash

# Backup data from Epiphany using backup-monitor's scripts.
#
# Author: Thibauld Nion
# License: Public Domain


# A name that will identify the data once backed up
BKP_NAME=Epiphany

# directory where application's data will be copied before the rsync
BDIR_TEMP_PARENT=$HOME/BackupTemp
BDIR_TEMP=$BDIR_TEMP_PARENT/$BKP_NAME


cleanup_temp_dir ()
{ # Remove the temporary directory used for rsync
    rm -rf $BDIR_TEMP_PARENT
    if [ $? -ne 0 ]; then
	echo "Unable to delete the temp folder: " $BDIR_TEMP
	exit 1
    fi;
}


echo "Preparing the backup with a local copy"
# create the directories that will temporarily gather the data to be backed up
install -d $BDIR_TEMP

# make a local copy (ease the rsync process when copied data is not too big)
cp $HOME/.gnome2/epiphany/bookmarks.rdf $BDIR_TEMP
cp $HOME/.gnome2/epiphany/ephy-bookmarks.xml $BDIR_TEMP
if [ $? -ne 0 ]; then
	echo "Error when copying" $BKP_NAME"'s data !"
	cleanup_temp_dir
	exit 1
fi;


echo "Achieving the backup"
# start the backup of the gathered data
$BACKUP_MONITOR_RSYNC_SCRIPT $BDIR_TEMP $BACKUP_MONITOR_DESTINATION_FOLDER

# at the end clean the temporary folder
echo "Cleaning up temporary folder"
cleanup_temp_dir
