#!/bin/bash

# Backup data from Evolution using backup-monitor's' scripts.
#
# Author: Thibauld Nion
# License: GPLv3
#


# A name that will identify the data once backed up
BKP_NAME=Evolution

# directory where application's data will be copied before the rsync
BDIR_TEMP_PARENT=$HOME/BackupTemp
BDIR_TEMP=$BDIR_TEMP_PARENT/$BKP_NAME


cleanup_temp_dir ()
{ # Remove the temporary directory used for rsync
    rm -rf $BDIR_TEMP_PARENT
    if [ $? -ne 0 ]; then
	echo "Unable to delete the temp folder: " $BDIR_TEMP
	exit 1
    fi;
}


echo "Preparing the backup with a local copy"
# create the directories that will temporarily gather the data to be backed up
install -d $BDIR_TEMP


#----------------------------------------------------------------------
# Backup code taken from an external script found at: 
# http://www.tux-planet.fr/evolution-backup-script/
#-----------------------------------------------------------------------#
#                                                                       #
# Description : Backup an evolution profil                              #
# OS          : Linux                                                   #
# Licence     : GPLv3                                                   #
# Requires    : evolution - tar                                         #
# Version     : 0.1.4                                                   #
# Author      : Sebastien Bilbeau <sebastien.bilbeau CHEZ gmail.com>    #
# Web site    : http://www.tux-planet.fr/                               #
#                                                                       #
#-----------------------------------------------------------------------#


# Set script variable
USER=$(id -un)
GROUP=$(id -gn)
DATE=`date "+%F"`

# Thibauld: this line is to adapt to backup-monitor's rsync script
BKP_ARCHIVE_NAME=$BDIR_TEMP/bkp-evolution-$DATE.tar.bz2


# Go to user homedir
clear
cd /home/$USER

# Shutdown application
gconftool-2 --shutdown
evolution --force-shutdown

# Backup evolution setting
gconftool-2 --dump /apps/evolution > evolution_setting.xml

# Make a restore help file
/bin/cat > RESTORE_README.txt <<FINCONFIG
#!/bin/bash
# To restore your evolution profil, after extract this archive file,
# use the following command :

cd /home/$USER
gconftool-2 --shutdown
evolution --force-shutdown
tar jxvf bkp-evolution-$DATE.tar.bz2
gconftool-2 --unload evolution_setting.xml 
gconftool-2 --load evolution_setting.xml
rm -f evolution_setting.xml
FINCONFIG

# Compress and backup
nice -n +10 tar cvfj $BKP_ARCHIVE_NAME --exclude=.evolution/mail/imap .evolution .gconf/apps/evolution .camel_certs evolution_setting.xml RESTORE_README.txt

if [ $? -ne 0 ]; then
	echo "Error while archiving Evolution's data !"
	cleanup_temp_dir
	exit 1
fi;

# Remove tmp files
rm -f evolution_setting.xml
rm -f RESTORE_README.txt

# Change owner (for crontab use)
chown $USER:$GROUP $BKP_ARCHIVE_NAME
#----------------------------------------------------------------------


echo "Achieving the backup"
# start the backup of the gathered data
$BACKUP_MONITOR_RSYNC_SCRIPT $BDIR_TEMP $BACKUP_MONITOR_DESTINATION_FOLDER

# at the end clean the temporary folder
echo "Cleaning up temporary folder"
cleanup_temp_dir
