#!/bin/bash

# Launch a backup of a given directory.
#
# Note: The directory name must be one of the XDG users dir (usually
# defined in .config/user-dirs.dirs)
#
# Author: Thibauld Nion
# License: Public Domain

# Get the XDG name of the directory to backup
BDIR_XDG_NAME=$1

# The name of the corresponding environment variable
BDIR_XDG_VARIABLE_NAME=XDG_${BDIR_XDG_NAME}_DIR

# get its name from xdg-user-dirs but check for xdg availability before that
# see also http://www.freedesktop.org/wiki/Software/xdg-user-dirs
if [ ! -r ${XDG_CONFIG_HOME:-~/.config}/user-dirs.dirs ]; then
    echo "ERROR: xdg-user-dirs is not installed or used !" >&2
    exit 1
fi;
source ${XDG_CONFIG_HOME:-~/.config}/user-dirs.dirs
BDIR_MAIN_PATH=${!BDIR_XDG_VARIABLE_NAME}

# (optional) excludes file - this contains a wildcard pattern per line
# of files to exclude
#EXCLUDES=$HOME/.config/rsync-excludes

if [ "$BDIR_MAIN_PATH" = "" ]; then
    echo "ERROR: couldn't find XDG directory for" $BDIR_XDG_NAME >&2
    exit 1
fi;

# start the backup
$BACKUP_MONITOR_RSYNC_SCRIPT $BDIR_MAIN_PATH $BACKUP_MONITOR_DESTINATION_FOLDER # $EXCLUDES
